==> qmapshack_1.16.1.orig.tar.gz: qmapshack-V_1.16.1/src/qmapshack/gis/trk/filter/CFilterSpeedConst.cpp <==
/**********************************************************************************************
    Copyright (C) 2018 Oliver Eichler <oliver.eichler@gmx.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

**********************************************************************************************/

#include "gis/trk/CGisItemTrk.h"
#include "gis/trk/filter/CFilterSpeedConst.h"

#include <QtWidgets>

CFilterSpeedConst::CFilterSpeedConst(QWidget* parent)
    : QWidget(parent)
{
    setupUi(this);
}

void CFilterSpeedConst::loadSettings(QSettings& cfg)
{
    spinConstantSpeed->setValue(cfg.value("speed", 18.0 * IUnit::self().speedFactor).toDouble() * IUnit::self().speedFactor);
}

void CFilterSpeedConst::saveSettings(QSettings& cfg)
{
    cfg.setValue("speed", spinConstantSpeed->value() / IUnit::self().speedFactor);
}

void CFilterSpeedConst::apply(CGisItemTrk& trk)
{
    trk.filterSpeed(spinConstantSpeed->value() / IUnit::self().speedFactor);
}

==> qmapshack_1.18.1.orig.tar.gz: qmapshack-V_1.18.1/src/qmapshack/gis/trk/filter/CFilterSpeedConst.cpp <==
/**********************************************************************************************
    Copyright (C) 2018 Oliver Eichler <oliver.eichler@gmx.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

**********************************************************************************************/

#include "gis/trk/filter/CFilterSpeedConst.h"

#include <QtWidgets>

#include "gis/trk/CGisItemTrk.h"

CFilterSpeedConst::CFilterSpeedConst(QWidget* parent) : QWidget(parent) { setupUi(this); }

void CFilterSpeedConst::loadSettings(QSettings& cfg) {
  spinConstantSpeed->setValue(cfg.value("speed", 18.0 * IUnit::self().speedFactor).toDouble() *
                              IUnit::self().speedFactor);
}

void CFilterSpeedConst::saveSettings(QSettings& cfg) {
  cfg.setValue("speed", spinConstantSpeed->value() / IUnit::self().speedFactor);
}

void CFilterSpeedConst::apply(CGisItemTrk& trk) {
  trk.filterSpeed(spinConstantSpeed->value() / IUnit::self().speedFactor);
}
